@@ -16,23 +16,25 @@ def mail(subject, context, template, from_email, to_email, connection=None, repl
 	txt_template = render_to_string(template + '.txt', context)
 
 	# email debug mode
-	if hasattr(settings, 'EMAIL_DEBUG'):
-		if not cc:
-			cc = []
-		if not bcc:
-			bcc = []
+	email_mode = getattr(settings, HELPFUL_EMAIL_MODE, 'BLANK')
+	email_debug_info = getattr(settings, HELPFUL_EMAIL_DEBUG_INFO, False)
+	email_debug_to_email = getattr(settings, HELPFUL_EMAIL_DEBUG_TO_EMAIL, [])
 
-		if hasattr(settings, 'EMAIL_DEBUG_INFO') and settings.EMAIL_DEBUG_INFO:
-			pre_info = 'to_email: ' + ', '.join(to_email) + '\n'\
-							+ 'cc: ' + ', '.join(cc) + '\n'\
-							+ 'bcc: ' + ', '.join(bcc)
+	if email_mode == 'PROD':
+		pass
+	elif email_mode == 'DEBUG':
+		if email_debug_info:
+			pre_info = 'to_email: ' + ', '.join(to_email) + '\n' \
+					   + 'cc: ' + ', '.join(cc) + '\n' \
+					   + 'bcc: ' + ', '.join(bcc)
 			html_template = '<pre>' + pre_info + '\n\n</pre>' + html_template
 			txt_template = pre_info + '\n\n' + txt_template
-
-		to_email = settings.EMAIL_DEBUG
-		cc = None
-		bcc = None
-	elif settings.DEBUG:
+		to_email = email_debug_to_email
+		cc = []
+		bcc = []
+	elif email_mode == 'BLANK':
+		return
+	else:
 		return
 
 	plinper = pynliner.Pynliner()
